@@ -121,7 +121,7 @@ class AsyncBaseClient:
 
     ??? example "Context manager example"
         ```py
-        with AsyncBaseClient("secrets.json") as client:
+        async with AsyncBaseClient("secrets.json") as client:
             await client.teardown()
         ```
     """
@@ -146,7 +146,13 @@ class AsyncBaseClient:
             )
 
         self._secrets = oidc.Secrets.from_file(secrets_file)
-        self._session = session or ClientSession(loop=self._loop, **kwargs)
+
+        with warnings.catch_warnings():
+            # Suppress that annoying warning about ClientSession only
+            # being creatable in an async function, while allowing other
+            # deprecation warnings to be logged.
+            warnings.simplefilter("ignore", DeprecationWarning)
+            self._session = session or ClientSession(loop=self._loop, **kwargs)
 
         if not os.environ.get("PYTEST_CURRENT_TEST"):
             # This causes issues when run in testing, so we'll just make
@@ -278,9 +284,9 @@ class AsyncClient(AsyncBaseClient):
 
     ??? example "Context manager example"
         ```py
-        with AsyncClient("secrets.json") as client:
+        async with AsyncClient("secrets.json") as client:
             # Perform operations here.
-            await client.teardown()
+            print(client)
         ```
 
     ??? example "Advanced example"
@@ -334,6 +340,17 @@ class AsyncClient(AsyncBaseClient):
         self._active_tokens: str | None = None
         self._shard: Shard | None = None
 
+    async def __aenter__(self) -> AsyncClient:
+        return self
+
+    async def __aexit__(
+        self,
+        exc_type: type[BaseException] | None,
+        exc_value: BaseException | None,
+        exc_tb: TracebackType | None,
+    ) -> None:
+        await self.teardown()
+
     @property
     def active_tokens(self) -> str | None:
         return self._active_tokens
@@ -520,7 +537,7 @@ class Client:
         ```py
         with Client("secrets.json") as client:
             # Perform operations here.
-            client.teardown()
+            print(client)
         ```
 
     ??? example "Advanced example"
