@@ -33,12 +33,14 @@ __all__ = ("ReportQuery", "GroupQuery", "GroupItemQuery")
 import datetime as dt
 import logging
 import typing as t
+import warnings
 
 import analytix
 from analytix.abc import ReportType
 from analytix.errors import InvalidRequest
 from analytix.reports import data
 from analytix.reports import types as rt
+from analytix.warnings import InvalidMonthFormatWarning
 
 _log = logging.getLogger(__name__)
 
@@ -115,7 +117,7 @@ class ReportQuery:
         )
 
     def validate(self) -> None:
-        _log.info("Validating request...")
+        _log.info("Validating request")
 
         if self.max_results < 0:
             raise InvalidRequest(
@@ -133,9 +135,10 @@ class ReportQuery:
 
         if "month" in self.dimensions:
             if self._start_date.day != 1 or self._end_date.day != 1:
-                _log.warning(
+                warnings.warn(
                     "Correcting start and end dates -- if 'month' is passed as a "
-                    "dimension, these should always be the first day of the month"
+                    "dimension, these should always be the first day of the month",
+                    InvalidMonthFormatWarning,
                 )
                 self._start_date = dt.date(
                     self._start_date.year, self._start_date.month, 1
@@ -159,12 +162,19 @@ class ReportQuery:
             ]
             _log.debug("Metrics set to: " + ", ".join(self.metrics))
 
+        diff = set(o.strip("-") for o in self.sort_options) - set(self.metrics)
+        if diff:
+            raise InvalidRequest(
+                "some sort options do not match metrics: " + ", ".join(diff)
+            )
+
         self.rtype.validate(
             self.dimensions,
             self.filters,
             self.metrics,
             self.sort_options,
             self.max_results,
+            self.start_index,
         )
 
         # If it gets to this point, it's fine.
